@@ -1,3 +1,4 @@
+# BEGIN { $Pegex::Bootstrap = 1 }
 use lib "$ENV{HOME}/src/pegex-pm/lib";
 use Pegex::Compiler;
 
@@ -14,7 +15,7 @@ print <<"...";
 # license:   perl
 # copyright: 2010, 2011
 
-package Pegex::Grammar::Pegex;
+package Pegex::Pegex::Grammar;
 use Pegex::Mo;
 extends 'Pegex::Grammar';
 
